@@ -3,7 +3,7 @@ package Plack::Middleware::XSRFBlock;
 {
   $Plack::Middleware::XSRFBlock::DIST = 'Plack-Middleware-XSRFBlock';
 }
-$Plack::Middleware::XSRFBlock::VERSION = '0.0.17';
+$Plack::Middleware::XSRFBlock::VERSION = '0.0.18';
 use strict;
 use warnings;
 use parent 'Plack::Middleware';
@@ -340,12 +340,13 @@ sub xsrf_detected {
         ? sprintf('XSRF detected [%s]', $args->{msg})
         : 'XSRF detected';
 
-    $self->log(error => "$msg, returning HTTP_FORBIDDEN");
-
     if (my $app_for_blocked = $self->blocked) {
+        $self->log(info => "$msg, invoking `blocked` coderef");
         return $app_for_blocked->($env, $msg, app => $self->app);
     }
 
+    $self->log(error => "$msg, returning HTTP_FORBIDDEN");
+
     return [
         HTTP_FORBIDDEN,
         [ 'Content-Type' => 'text/plain', 'Content-Length' => length($msg) ],
@@ -393,7 +394,7 @@ Plack::Middleware::XSRFBlock - Block XSRF Attacks with minimal changes to your a
 
 =head1 VERSION
 
-version 0.0.17
+version 0.0.18
 
 =head1 SYNOPSIS
 
@@ -731,7 +732,7 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andrey Khozov Chisel Daniel Perrett Gianni Ceccarelli Karen Etheridge Matthew Ryall Matthias Zeichmann Michael Kröll Sebastian Willert Sterling Hanenkamp William Wolf
+=for stopwords Andrey Khozov Ashley Pond V Chisel Daniel Perrett Gianni Ceccarelli Karen Etheridge Matthew Ryall Matthias Zeichmann Michael Kröll Sebastian Willert Sterling Hanenkamp William Wolf
 
 =over 4
 
@@ -741,6 +742,10 @@ Andrey Khozov <andrey@rydlab.ru>
 
 =item *
 
+Ashley Pond V <ashley.pond.v@gmail.com>
+
+=item *
+
 Chisel <chisel.wright@net-a-porter.com>
 
 =item *
